@@ -46,20 +46,20 @@ def create(config):
     "-gt",
     type=click.Choice(
         [
-            "GTX 1060",
-            "RTX 2060 Super",
-            "RTX 2070 Super",
-            "RTX 2080 Ti",
-            "RTX 3090",
-            "K80",
-            "P100",
-            "T4",
-            "V100",
-            "A100",
+            "gtx1060",
+            "rtx2060s",
+            "rtx2070s",
+            "rtx2080ti",
+            "rtx3090",
+            "k80",
+            "p100",
+            "t4",
+            "v100",
+            "a100",
         ],
         case_sensitive=False,
     ),
-    default="RTX 2080 Ti",
+    default="rtx2080ti",
     show_default=True,
     help="GPU type.",
 )
@@ -88,17 +88,11 @@ def create(config):
             "DEEPLEARNING_PY37",
             "PYTORCH_PY38_19",
             "PYTORCH_PY38_18",
-            "PYTORCH_PY38_17",
             "PYTORCH_PY37_17",
-            "PYTORCH_PY37_16",
-            "PYTORCH_PY37_15",
             "TENSORFLOW_PY38_25",
             "TENSORFLOW_PY38_24",
             "TENSORFLOW_PY37_23",
-            "TENSORFLOW_PY37_22",
-            "TENSORFLOW_PY37_114",
             "MXNET_PY38_18",
-            "MXNET_PY38_17",
             "MXNET_PY37_16",
         ],
         case_sensitive=False,
@@ -107,6 +101,12 @@ def create(config):
     show_default=True,
     help="Job environment to use",
 )
+@click.option(
+    "--custom-image",
+    type=click.STRING,
+    help="Docker Image to use for the job.  Implies 'CUSTOM' environment type.",
+    multiple=True,
+)
 @click.option(
     "--env",
     type=click.STRING,
@@ -169,6 +169,7 @@ def notebook(
     dataset,
     public_dataset,
     environment,
+    custom_image,
     env,
     key,
     apt_packages,
@@ -189,7 +190,11 @@ def notebook(
 
     options = dict(
         data=dict(datasets=datasets),
-        environment=dict(type=environment, worker_key_types=[k for k in key]),
+        environment=dict(
+            type="CUSTOM" if custom_image else environment,
+            custom_image=custom_image,
+            worker_key_types=[k for k in key],
+        ),
     )
 
     try:
@@ -301,20 +306,20 @@ def notebook(
     "-gt",
     type=click.Choice(
         [
-            "GTX 1060",
-            "RTX 2060 Super",
-            "RTX 2070 Super",
-            "RTX 2080 Ti",
-            "RTX 3090",
-            "K80",
-            "P100",
-            "T4",
-            "V100",
-            "A100",
+            "gtx1060",
+            "rtx2060s",
+            "rtx2070s",
+            "rtx2080ti",
+            "rtx3090",
+            "k80",
+            "p100",
+            "t4",
+            "v100",
+            "a100",
         ],
         case_sensitive=False,
     ),
-    default="RTX 2080 Ti",
+    default="rtx2080ti",
     show_default=True,
     help="GPU type.",
 )
@@ -361,17 +366,11 @@ def notebook(
             "DEEPLEARNING_PY37",
             "PYTORCH_PY38_19",
             "PYTORCH_PY38_18",
-            "PYTORCH_PY38_17",
             "PYTORCH_PY37_17",
-            "PYTORCH_PY37_16",
-            "PYTORCH_PY37_15",
             "TENSORFLOW_PY38_25",
             "TENSORFLOW_PY38_24",
             "TENSORFLOW_PY37_23",
-            "TENSORFLOW_PY37_22",
-            "TENSORFLOW_PY37_114",
             "MXNET_PY38_18",
-            "MXNET_PY38_17",
             "MXNET_PY37_16",
         ],
         case_sensitive=False,
@@ -380,6 +379,12 @@ def notebook(
     show_default=True,
     help="Job environment to use",
 )
+@click.option(
+    "--custom-image",
+    type=click.STRING,
+    help="Docker Image to use for the job.  Implies 'CUSTOM' environment type.",
+    multiple=True,
+)
 @click.option(
     "--env",
     type=click.STRING,
@@ -450,6 +455,7 @@ def training(
     output_type,
     output_uri,
     environment,
+    custom_image,
     env,
     key,
     apt_packages,
@@ -471,7 +477,11 @@ def training(
 
     options = dict(
         data=dict(datasets=datasets),
-        environment=dict(type=environment, worker_key_types=[k for k in key]),
+        environment=dict(
+            type="CUSTOM" if custom_image else environment,
+            custom_image=custom_image,
+            worker_key_types=[k for k in key],
+        ),
     )
 
     if output_type:
@@ -582,20 +592,20 @@ def training(
     "-gt",
     type=click.Choice(
         [
-            "GTX 1060",
-            "RTX 2060 Super",
-            "RTX 2070 Super",
-            "RTX 2080 Ti",
-            "RTX 3090",
-            "K80",
-            "P100",
-            "T4",
-            "V100",
-            "A100",
+            "gtx1060",
+            "rtx2060s",
+            "rtx2070s",
+            "rtx2080ti",
+            "rtx3090",
+            "k80",
+            "p100",
+            "t4",
+            "v100",
+            "a100",
         ],
         case_sensitive=False,
     ),
-    default="RTX 2080 Ti",
+    default="rtx2080ti",
     show_default=True,
     help="GPU type.",
 )
@@ -643,17 +653,11 @@ def training(
             "DEEPLEARNING_PY37",
             "PYTORCH_PY38_19",
             "PYTORCH_PY38_18",
-            "PYTORCH_PY38_17",
             "PYTORCH_PY37_17",
-            "PYTORCH_PY37_16",
-            "PYTORCH_PY37_15",
             "TENSORFLOW_PY38_25",
             "TENSORFLOW_PY38_24",
             "TENSORFLOW_PY37_23",
-            "TENSORFLOW_PY37_22",
-            "TENSORFLOW_PY37_114",
             "MXNET_PY38_18",
-            "MXNET_PY38_17",
             "MXNET_PY37_16",
         ],
         case_sensitive=False,
@@ -662,6 +666,12 @@ def training(
     show_default=True,
     help="Job environment to use",
 )
+@click.option(
+    "--custom-image",
+    type=click.STRING,
+    help="Docker Image to use for the job.  Implies 'CUSTOM' environment type.",
+    multiple=True,
+)
 @click.option(
     "--env",
     type=click.STRING,
@@ -731,6 +741,7 @@ def inference(
     output_type,
     output_uri,
     environment,
+    custom_image,
     env,
     key,
     apt_packages,
@@ -748,7 +759,11 @@ def inference(
 
     options = dict(
         data=dict(datasets=[]),
-        environment=dict(type=environment, worker_key_types=[k for k in key]),
+        environment=dict(
+            type="CUSTOM" if custom_image else environment,
+            custom_image=custom_image,
+            worker_key_types=[k for k in key],
+        ),
     )
 
     if input_type:
@@ -885,20 +900,20 @@ def from_json(config, attach, connect, file):
     "-gt",
     type=click.Choice(
         [
-            "GTX 1060",
-            "RTX 2060 Super",
-            "RTX 2070 Super",
-            "RTX 2080 Ti",
-            "RTX 3090",
-            "K80",
-            "P100",
-            "T4",
-            "V100",
-            "A100",
+            "gtx1060",
+            "rtx2060s",
+            "rtx2070s",
+            "rtx2080ti",
+            "rtx3090",
+            "k80",
+            "p100",
+            "t4",
+            "v100",
+            "a100",
         ],
         case_sensitive=False,
     ),
-    default="RTX 2080 Ti",
+    default="rtx2080ti",
     show_default=True,
     help="GPU type.",
 )
@@ -910,17 +925,11 @@ def from_json(config, attach, connect, file):
             "DEEPLEARNING_PY37",
             "PYTORCH_PY38_19",
             "PYTORCH_PY38_18",
-            "PYTORCH_PY38_17",
             "PYTORCH_PY37_17",
-            "PYTORCH_PY37_16",
-            "PYTORCH_PY37_15",
             "TENSORFLOW_PY38_25",
             "TENSORFLOW_PY38_24",
             "TENSORFLOW_PY37_23",
-            "TENSORFLOW_PY37_22",
-            "TENSORFLOW_PY37_114",
             "MXNET_PY38_18",
-            "MXNET_PY38_17",
             "MXNET_PY37_16",
         ],
         case_sensitive=False,
@@ -929,6 +938,12 @@ def from_json(config, attach, connect, file):
     show_default=True,
     help="Job environment to use",
 )
+@click.option(
+    "--custom-image",
+    type=click.STRING,
+    help="Docker Image to use for the job.  Implies 'CUSTOM' environment type.",
+    multiple=True,
+)
 @click.option(
     "--env",
     type=click.STRING,
@@ -994,6 +1009,7 @@ def endpoint(
     gpu_count,
     gpu_type,
     environment,
+    custom_image,
     env,
     key,
     apt_packages,
@@ -1011,7 +1027,11 @@ def endpoint(
     routes = [json.loads(item) for item in route]
 
     options = dict(
-        environment=dict(type=environment, worker_key_types=[k for k in key]),
+        environment=dict(
+            type="CUSTOM" if custom_image else environment,
+            custom_image=custom_image,
+            worker_key_types=[k for k in key],
+        ),
     )
 
     try:
