@@ -148,8 +148,7 @@ class Dataset:
         await self.trainml._query(f"/dataset/pub/{self._id}", "DELETE")
 
     def _get_msg_handler(self, msg_handler):
-        def handler(msg):
-            data = json.loads(msg.data)
+        def handler(data):
             if data.get("type") == "subscription":
                 if msg_handler:
                     msg_handler(data)
